package com.ruoyi.system.mapper;

import com.ruoyi.system.domain.ActSuppliesRole;
import com.ruoyi.system.domain.ActSuppliesTemplate;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * 物资管理Mapper接口
 * 
 * @author
 * @date
 */
@Repository
public interface ActSuppliesTemplateMapper
{

    List<ActSuppliesTemplate> selectSuppliesTemplateList(ActSuppliesTemplate sysSupplies);

    List<ActSuppliesTemplate> selectSuppliesTemplateById(Long id);

    List<ActSuppliesTemplate> selectSuppliesTemplateByIdNoId(Long id);

    int insertSuppliesTemplate(ActSuppliesTemplate sysSupplies);

//    List<ActSuppliesTemplate> selectlistnameid();

    int updateSuppliesTemplate(ActSuppliesTemplate sysSupplies);

    int deleteSuppliesTemplateById(Long ids);

    int deleteSuppliesTemplateByIds(Long[] ids);

    int updateSuppliesTemplateByIds(Long[] ids);

    List<ActSuppliesTemplate> saveTemplate(Long id);

    Long findall(Long ids);

    List<Integer> find(Long id);

    List<String> findName();

    List<ActSuppliesTemplate> saveTemplateStatus(Long[] ids);

    void updateRelease(ActSuppliesTemplate actSuppliesTemplate);

    ActSuppliesRole selectActSuppliesRoleById(Integer id);

    List<ActSuppliesRole> selectActSuppliesRoleList(Integer id);

    int updateActSuppliesRole(ActSuppliesRole actSuppliesRole);

    int selectHistory(Long id);
}